head(res26); head(res13)

#############################
### Datasets construction ###
#############################

mean_Rapp <- read.table("Rapp_cell_mean.txt", h=T)
mean_Tpp <- read.table("Tpp_cell_mean.txt", h=T)

# tests to verify cell order
length(which(as.character(mean_Rapp$Name) == as.character(mean_Tpp$Name)))
length(which(mean_Rapp$Lon == mean_Tpp$Lon))
length(which(mean_Rapp$Lat == mean_Tpp$Lat))

d.df <- mean_Rapp[, c(2, 4, 5, 3)] 

d.df$Indicus_BTA26 <- rep(NA, nrow(d.df)); head(d.df)
head(res26)
for (i in 1:nrow(d.df)) {
  to <- which(as.character(d.df$Name[i]) == as.character(res26$cell))
  d.df[i, 5] <- res26[to, 3]
  rm(to)
  }; rm(i); head(d.df)

d.df$Tpp_cell_mean <- mean_Tpp$Tpp_cell_mean; head(d.df)
d.df$Indicus_BTA13 <- rep(NA, nrow(d.df)); head(d.df)
head(res13)
for (i in 1:nrow(d.df)) {
  to <- which(as.character(d.df$Name[i]) == as.character(res13$cell))
  d.df[i, 7] <- res13[to, 3]
  rm(to)
  }; rm(i); head(d.df)

range(d.df$Indicus_BTA26); range(d.df$Indicus_BTA13)
d.df$Indicus_BTA26_transformed <- (d.df$Indicus_BTA26*(nrow(d.df) - 1) + 0.5)/nrow(d.df)
d.df$Indicus_BTA13_transformed <- (d.df$Indicus_BTA13*(nrow(d.df) - 1) + 0.5)/nrow(d.df)
range(d.df$Indicus_BTA26_transformed); range(d.df$Indicus_BTA13_transformed)

##############################
### Beta regression models ###
##############################

library(betareg)

### --> BTA-113604 (Chr 26)

cor(d.df[, c(2:4)])

model_logit_Chr26 <- betareg(Indicus_BTA26_transformed ~ Rapp_cell_mean + Lon + Lat, link="logit", data = d.df)
summary(model_logit_Chr26)
model_logit_Chr26$pseudo.r.squared
par(mfrow=c(2, 3))
plot(model_logit_Chr26, which = 1:4, type = "pearson", pch=21, col="red", cex=1)
plot(model_logit_Chr26, which = 5, type = "deviance", sub.caption = "", pch=21, col="red", cex=1)
plot(model_logit_Chr26, which = 1, type = "deviance", sub.caption = "", pch=21, col="red", cex=1)
new <- cbind(getValues(Rapp),
             xyFromCell(object = Rapp, cell = cellsFromExtent(object = Rapp, extent = extent(Rapp))))  
colnames(new) <- c("Rapp_cell_mean", "Lon", "Lat")
new <- as.data.frame(new); head(new)
new <- predict(object = model_logit_Chr26, newdata = new)
indicus_proportion_Chr26 <- Rapp
indicus_proportion_Chr26 <- setValues(indicus_proportion_Chr26, new) 
plot(stack(Rapp, indicus_proportion_Chr26))
###
model_logit_Chr26_2 <- betareg(Indicus_BTA26_transformed ~ Rapp_cell_mean, link="logit", data = d.df)
summary(model_logit_Chr26_2)
model_logit_Chr26_2$pseudo.r.squared
par(mfrow=c(2, 3))
plot(model_logit_Chr26_2, which = 1:4, type = "pearson", pch=21, col="red", cex=1)
plot(model_logit_Chr26_2, which = 5, type = "deviance", sub.caption = "", pch=21, col="red", cex=1)
plot(model_logit_Chr26_2, which = 1, type = "deviance", sub.caption = "", pch=21, col="red", cex=1)
new2 <- data.frame(getValues(Rapp))  
colnames(new2) <- c("Rapp_cell_mean"); head(new2)
new2 <- predict(object = model_logit_Chr26_2, newdata = new2)
indicus_proportion_Chr26_2 <- Rapp
indicus_proportion_Chr26_2 <- setValues(indicus_proportion_Chr26_2, new2) 

### plot
library(mapmisc)
library(rasterVis)
library(RColorBrewer)
library(plotly)
py <- plotly()
# break_points_prob <- seq(0, 1, 0.0001)
mycols <-colorRampPalette(c("royalblue", "yellow", "red"), interpolate = "spline")(10001)
# mycols <-colorRampPalette(c("gray95", "gray50", "gray45", "gray40", "gray35", "black"), interpolate = "spline")(10001)
# legend_prob <- list(at = c(0.00, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90, 1.00), labels = c("0.00", "0.10", "0.20", "0.30", "0.40", "0.50", "0.60", "0.70", "0.80", "0.90", "1.00"))
# myTheme=rasterTheme(region=brewer.pal('spectral', n=11))
# levelplot(Rapp, par.settings = myTheme, margin = F, main = expression(psi[R]))
# plot(uganda, add=T)

brk <- seq(0, 1, 0.1)

png("Local ancestry map - BTA26 - BTA-113604.png", width	= 1100, height = 600, res = 120)
par(mfrow=c(1,2), mar=c(2, 2, 2.5, 5), oma=c(3, 2, 3, 2))
plot(Rapp, 
     xlim=c(4.5e+05, 10.7e+05), 
     ylim=c(-2e+05, 5.3e+05),
     breaks=brk, 
     col=rev(colorRampPalette(brewer.pal(10, "Spectral"))(10)), 
     legend=F,
     axes=FALSE,
     main="Vector distribution")
scaleBar(proj4string(uganda), pos = "bottomright", outer=F, cex = 1, pt.cex = 0, seg.len = 3, bty="n")
plot(Rapp, 
     breaks=brk, 
     legend.only=TRUE, 
     col=rev(colorRampPalette(brewer.pal(10, "Spectral"))(10)), 
     legend.width=1, legend.shrink=0.5, smallplot=c(0.82, 0.89, 0.1, 0.8),
     legend.args=list(text=expression(psi[R]), cex=1.2),
     axis.args=list(cex.axis=1.1))
plot(uganda, lwd=1, add=T)
text(5e+05, 4.9e+05, "(a)", cex=1.2)

plot(indicus_proportion_Chr26_2, 
     xlim=c(4.5e+05, 10.7e+05), 
     ylim=c(-2e+05, 5.3e+05),
     breaks=brk, 
     col=rev(colorRampPalette(brewer.pal(10, "Spectral"))(10)), 
     legend=F,
     axes=FALSE,
     main=paste("Zebuine ancestry", "at BTA-113604", sep="\n"))
scaleBar(proj4string(uganda), pos = "bottomright", outer=F, cex = 1, pt.cex = 0, seg.len = 3, bty="n")
plot(indicus_proportion_Chr26_2, 
     breaks=brk, 
     legend.only=TRUE, 
     col=rev(colorRampPalette(brewer.pal(10, "Spectral"))(10)), 
     legend.width=1, legend.shrink=0.5, smallplot=c(0.82, 0.89, 0.1, 0.8),
     legend.args=list(text="THA", cex=1.2),
     axis.args=list(cex.axis=1.1))
plot(uganda, lwd=1, add=T)
text(5e+05, 4.9e+05, "(b)", cex=1.2)
dev.off()

### --> ARS-110102/ARS-24867 (Chr 13)

cor(d.df[, c(2, 3, 6)])

model_logit_Chr13 <- betareg(Indicus_BTA13_transformed ~ Tpp_cell_mean + Lon, link="logit", data = d.df)
summary(model_logit_Chr13)
model_logit_Chr13$pseudo.r.squared
par(mfrow=c(2, 3))
plot(model_logit_Chr13, which = 1:4, type = "pearson", pch=16)
plot(model_logit_Chr13, which = 5, type = "deviance", sub.caption = "", pch=16)
plot(model_logit_Chr13, which = 1, type = "deviance", sub.caption = "", pch=16)
###
model_logit_Chr13_2 <- betareg(Indicus_BTA13_transformed ~ Tpp_cell_mean, link="logit", data = d.df)
summary(model_logit_Chr13_2)
model_logit_Chr13_2$pseudo.r.squared
par(mfrow=c(2, 3))
plot(model_logit_Chr13_2, which = 1:4, type = "pearson", pch=16)
plot(model_logit_Chr13_2, which = 5, type = "deviance", sub.caption = "", pch=16)
plot(model_logit_Chr13_2, which = 1, type = "deviance", sub.caption = "", pch=16)

