library(maptools); library(scales); library(rgdal); library(mapplots); library(raster); library(mapmisc); library(rasterVis)

####################################################################################
### setting spatial parameters and loading required files for spatial represetnation
####################################################################################

crs <- CRS("+proj=aea +lat_1=20 +lat_2=-23 +lat_0=0 +lon_0=25 +x_0=0 +y_0=0 +datum=WGS84 +units=m +no_defs")

uganda <- readShapePoly("UgandaWithoutWater_epsg102022.shp", proj4string = crs)
crsgrid <- CRS("+proj=longlat +datum=WGS84 +no_defs"); grid <- readShapeLines("SamplingGrid.shp", proj4string = crsgrid)
grid <- spTransform(grid, CRSobj = crs)

centroidscells <- read.table("CentroidsCells.txt", h=T); centroidscells.wgs84 <- SpatialPoints(centroidscells[, c(1, 2)], proj4string = crsgrid)
centroidscells.epsg102022 <- spTransform(x = centroidscells.wgs84, CRSobj = crs); centroidscells.epsg102022 <- cbind(centroidscells$CellLabel, as.data.frame(centroidscells.epsg102022@coords)); colnames(centroidscells.epsg102022) <- c("cell", "lon", "lat")

Rapp <- raster("prediction.PC1PC2PC3.tif")
Tpp <- raster("model.original.tif")
colRapp <- colorRampPalette(c("gray95", "gray50", "gray45", "gray40", "gray35", "black"), interpolate = "spline")(1001)
colTpp <- colorRampPalette(c("gray95", "gray90", "gray50", "gray40", "gray35", "black"), interpolate = "spline")(1001)

##########
### chr 26
##########

la26 <- read.table("MUT_THA-chr26-windows9-13-results.txt", stringsAsFactors = F, h=T); head(la26)
cells26 <- unique(la26$cell)

for (i in 1:length(cells26)) {
  assign(cells26[i], subset(la26, la26$cell == cells26[i]))
  }; rm(i)
print(cells26)
cells.list26 <- list(J5, F3, B10, C6, D7, E3, E5, E7, F5, G2, G4, G6, H2, H3, H4, H6, I4, I5, I6, I7, J3, J4, B7, B8, B9, C10, C7, C8, C9, D2, D3, D4, D5, D6, D8, D9, E2, E4, E6, E8, E9, F2, F4, F6, F7, G3, G5, G7, H5, H7, I3); length(cells.list26)
res26 <- as.data.frame(matrix(rep(NA, 51*5), 51)); colnames(res26) <- c("cell", "MUT", "THA", "Lon", "Lat"); head(res26)
for (i in 1:length(cells.list26)) {
  res26[i, 1] <- unique(as.character(cells.list26[[i]]$cell))
  tot <- nrow(cells.list26[[i]])
  res26[i, 2] <- length(which(as.character(cells.list26[[i]]$Window13) == "MUT"))/tot
  res26[i, 3] <- length(which(as.character(cells.list26[[i]]$Window13) == "THA"))/tot
  res26[i, 4] <- centroidscells.epsg102022[which(unique(as.character(cells.list26[[i]]$cell)) == as.character(centroidscells.epsg102022[, 1])), 2]
  res26[i, 5] <- centroidscells.epsg102022[which(unique(as.character(cells.list26[[i]]$cell)) == as.character(centroidscells.epsg102022[, 1])), 3]
  }; rm(i); head(res26)

##########
### chr 13
##########

la <- read.table("MUT_THA-chr13-results.txt", stringsAsFactors = F, h=T)
cells <- unique(la$cell)
for (i in 1:length(cells)) {
  assign(cells[i], subset(la, la$cell == cells[i]))
  }; rm(i)
print(cells)
cells.list <- list(J5, F3, B10, C6, D7, E3, E5, E7, F5, G2, G4, G6, H2, H3, H4, H6, I4, I5, I6, I7, J3, J4, B7, B8, B9, C10, C7, C8, C9, D2, D3, D4, D5, D6, D8, D9, E2, E4, E6, E8, E9, F2, F4, F6, F7, G3, G5, G7, H5, H7, I3); length(cells.list)
res13 <- as.data.frame(matrix(rep(NA, 51*5), 51)); colnames(res13) <- c("cell", "MUT", "THA", "Lon", "Lat"); head(res13)
for (i in 1:length(cells.list)) {
  res13[i, 1] <- unique(as.character(cells.list[[i]]$cell))
  tot <- nrow(cells.list[[i]])
  res13[i, 2] <- length(which(as.character(cells.list[[i]]$Window145) == "MUT"))/tot
  res13[i, 3] <- length(which(as.character(cells.list[[i]]$Window145) == "THA"))/tot
  res13[i, 4] <- centroidscells.epsg102022[which(unique(as.character(cells.list[[i]]$cell)) == as.character(centroidscells.epsg102022[, 1])), 2]
  res13[i, 5] <- centroidscells.epsg102022[which(unique(as.character(cells.list[[i]]$cell)) == as.character(centroidscells.epsg102022[, 1])), 3]
  }; rm(i); head(res13); tail(res13, 20)

#################################################
### figure spatial distribution of local ancestry
#################################################

png("MUT_THA - Figure local ancestry.png", width = 1200, height = 600, res = 90)

par(mfrow=c(1, 3), mar=c(6, 1, 5, 0), oma=c(1, 4, 2, 0))#8

plot(Rapp,
     xlim=c(4.5e+05, 10.7e+05), ylim=c(-2.4e+05, 5.3e+05),
     col=colRapp,  
     xaxt = "n", yaxt = "n", legend=F,
     main="BTA-113604", sub="Chromosome 26, window 13", cex.main=2.5, cex.sub=2.3)
plot(grid, add=T, lty=1, lwd=2)
scaleBar(proj4string(uganda),  pos = "bottomright", outer=F, cex = 2, pt.cex = 0, seg.len = 5, bty="n")
mtext(text = "A", side = 3, line = -3.5, outer = F, at = c(5e+05), cex=1.5)
arrows(x0 = 5e+05, y0 = 3e+05, x1 = 5e+05, y1 = 4e+05, code = 2, length = 0.07, lty = 1, lwd = 2, col="black")
for (p in 1:nrow(res26)) {
  add.pie(z=c(res26[p, 2], res26[p, 3]), x=res26[p, 4], y=res26[p, 5], radius=25000, col=c(alpha("royalblue", 0.6), alpha("gold", 0.6)), labels="")
  }; rm(p)

plot(Tpp, bty="n",
     xlim=c(4.5e+05, 10.7e+05), ylim=c(-2.4e+05, 5.3e+05),
     col=colTpp,
     xaxt = "n", yaxt = "n", legend=F,
     main="ARS-110102/ARS-24867", sub="Chromosome 13, window 145", cex.main=2.5, cex.sub=2.3)
# plot(uganda, add=T)
plot(grid, add=T, lty=1, lwd=2)
scaleBar(proj4string(uganda),  pos = "bottomright", outer=F, cex = 2, pt.cex = 0, seg.len = 5, bty="n")
mtext(text = "B", side = 3, line = -3.5, outer = F, at = c(5e+05), cex=1.5)
arrows(x0 = 5e+05, y0 = 3e+05, x1 = 5e+05, y1 = 4e+05, code = 2, length = 0.07, lty = 1, lwd = 2, col="black")
for (p in 1:nrow(res13)) {
  add.pie(z=c(res13[p, 2], res13[p, 3]), x=res13[p, 4], y=res13[p, 5], radius=25000, col=c(alpha("royalblue", 0.6), alpha("gold", 0.6)), labels="")
  }; rm(p)

plot(1:10, 1:10, bty="n", ylab="", xlab="", axes=F, t="n")
legend("top", legend = c("Zebuine (THA)", "Taurine (MUT)"), cex = 3, pt.cex= 3, pch = c(22, 22),
       pt.bg=c("gold", "royalblue"))

dev.off()
