ls()
# install.packages("spatialEco"); 
library(maptools); library(rgdal); library(raster); library(spatialEco)

###############
### Input files
###############
crsgrid <- CRS("+proj=longlat +datum=WGS84 +no_defs")
grid <- readShapePoly("SamplingGrid.shp", proj4string = crsgrid); grid@data <- grid@data[, 1:2] 
grid <- spTransform(grid, CRSobj = crs); print(grid)
Rapp <- raster("prediction.PC1PC2PC3.tif")
Tpp <- raster("model.original.tif")
centroidscells <- read.table("CentroidsCells.txt", h=T)
entroidscells.wgs84 <- SpatialPoints(centroidscells[, c(1, 2)], proj4string = crsgrid)
centroidscells.epsg102022 <- spTransform(x = centroidscells.wgs84, CRSobj = crs); centroidscells.epsg102022 <- cbind(centroidscells$CellLabel, as.data.frame(centroidscells.epsg102022@coords)); colnames(centroidscells.epsg102022) <- c("cell", "lon", "lat")

####################################################
### Zonal statistics psi_R: mean and sd per cell ###
####################################################
Rapp_cell_mean <- zonal.stats(x = grid, y = Rapp, stat = mean, trace = T, plot = T)
Rapp_cell_mean <- cbind(grid@data, Rapp_cell_mean)
Rapp_cell_mean$Lon <- rep(NA, nrow(Rapp_cell_mean)); Rapp_cell_mean$Lat <- rep(NA, nrow(Rapp_cell_mean))
for (i in 1:nrow(Rapp_cell_mean)) {
  to <- which(as.character(Rapp_cell_mean$Name[i]) == as.character(centroidscells.epsg102022$cell))
  Rapp_cell_mean[i, 4] <- centroidscells.epsg102022[to, 2]
  Rapp_cell_mean[i, 5] <- centroidscells.epsg102022[to, 3]
  rm(to)
  }
write.table(Rapp_cell_mean, "Rapp_cell_mean.txt", row.names = FALSE, col.names = TRUE, sep="\t", quote=FALSE)

Rapp_cell_sd <- zonal.stats(x = grid, y = Rapp, stat = sd, trace = T, plot = T)
Rapp_cell_sd <- cbind(grid@data, Rapp_cell_sd)
Rapp_cell_sd$Lon <- rep(NA, nrow(Rapp_cell_sd)); Rapp_cell_sd$Lat <- rep(NA, nrow(Rapp_cell_sd))
for (i in 1:nrow(Rapp_cell_sd)) {
  to <- which(as.character(Rapp_cell_sd$Name[i]) == as.character(centroidscells.epsg102022$cell))
  Rapp_cell_sd[i, 4] <- centroidscells.epsg102022[to, 2]
  Rapp_cell_sd[i, 5] <- centroidscells.epsg102022[to, 3]
  rm(to)
  }
write.table(Rapp_cell_sd, "Rapp_cell_sd.txt", row.names = FALSE, col.names = TRUE, sep="\t", quote=FALSE)

Rapp_cell_median <- zonal.stats(x = grid, y = Rapp, stat = median, trace = T, plot = T)
Rapp_cell_median <- cbind(grid@data, Rapp_cell_median)
Rapp_cell_median$Lon <- rep(NA, nrow(Rapp_cell_median)); Rapp_cell_median$Lat <- rep(NA, nrow(Rapp_cell_median))
for (i in 1:nrow(Rapp_cell_median)) {
  to <- which(as.character(Rapp_cell_median$Name[i]) == as.character(centroidscells.epsg102022$cell))
  Rapp_cell_median[i, 4] <- centroidscells.epsg102022[to, 2]
  Rapp_cell_median[i, 5] <- centroidscells.epsg102022[to, 3]
  rm(to)
  }
write.table(Rapp_cell_median, "Rapp_cell_median.txt", row.names = FALSE, col.names = TRUE, sep="\t", quote=FALSE)

####################################################
### Zonal statistics gamma: mean and sd per cell ###
####################################################
Tpp_cell_mean <- zonal.stats(x = grid, y = Tpp, stat = mean, trace = T, plot = T)
Tpp_cell_mean <- cbind(grid@data, Tpp_cell_mean)
Tpp_cell_mean$Lon <- rep(NA, nrow(Tpp_cell_mean)); Tpp_cell_mean$Lat <- rep(NA, nrow(Tpp_cell_mean))
for (i in 1:nrow(Tpp_cell_mean)) {
  to <- which(as.character(Tpp_cell_mean$Name[i]) == as.character(centroidscells.epsg102022$cell))
  Tpp_cell_mean[i, 4] <- centroidscells.epsg102022[to, 2]
  Tpp_cell_mean[i, 5] <- centroidscells.epsg102022[to, 3]
  rm(to)
  }
write.table(Tpp_cell_mean, "Tpp_cell_mean.txt", row.names = FALSE, col.names = TRUE, sep="\t", quote=FALSE)

Tpp_cell_sd <- zonal.stats(x = grid, y = Tpp, stat = sd, trace = T, plot = T)
Tpp_cell_sd <- cbind(grid@data, Tpp_cell_sd)
Tpp_cell_sd$Lon <- rep(NA, nrow(Tpp_cell_sd)); Tpp_cell_sd$Lat <- rep(NA, nrow(Tpp_cell_sd))
for (i in 1:nrow(Tpp_cell_sd)) {
  to <- which(as.character(Tpp_cell_sd$Name[i]) == as.character(centroidscells.epsg102022$cell))
  Tpp_cell_sd[i, 4] <- centroidscells.epsg102022[to, 2]
  Tpp_cell_sd[i, 5] <- centroidscells.epsg102022[to, 3]
  rm(to)
  }
write.table(Tpp_cell_sd, "Tpp_cell_sd.txt", row.names = FALSE, col.names = TRUE, sep="\t", quote=FALSE)

Tpp_cell_median <- zonal.stats(x = grid, y = Tpp, stat = median, trace = T, plot = T)
Tpp_cell_median <- cbind(grid@data, Tpp_cell_median)
Tpp_cell_median$Lon <- rep(NA, nrow(Tpp_cell_median)); Tpp_cell_median$Lat <- rep(NA, nrow(Tpp_cell_median))
for (i in 1:nrow(Tpp_cell_median)) {
  to <- which(as.character(Tpp_cell_median$Name[i]) == as.character(centroidscells.epsg102022$cell))
  Tpp_cell_median[i, 4] <- centroidscells.epsg102022[to, 2]
  Tpp_cell_median[i, 5] <- centroidscells.epsg102022[to, 3]
  rm(to)
  }
write.table(Tpp_cell_median, "Tpp_cell_median.txt", row.names = FALSE, col.names = TRUE, sep="\t", quote=FALSE)
dev.off()
